@@ -223,7 +223,9 @@ class ArchiveSchema(object):
         # Sort columns based on their position and return a list of snapshot
         # columns.
         cols.sort(key=lambda x: x[2])
-        return [Column(colid=id, name=name) for id, name, _ in cols]
+        return [
+            Column(colid=id, name=name, colidx=pos) for id, name, pos in cols
+        ]
 
     def merge(
         self, columns, version, matching=MATCH_IDNAME, renamed=None,
